summaryrefslogtreecommitdiffstats
path: root/akregator/src/mk4storage/metakit/src/column.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/mk4storage/metakit/src/column.cpp')
-rw-r--r--akregator/src/mk4storage/metakit/src/column.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/akregator/src/mk4storage/metakit/src/column.cpp b/akregator/src/mk4storage/metakit/src/column.cpp
index 0873ac83..dda916ab 100644
--- a/akregator/src/mk4storage/metakit/src/column.cpp
+++ b/akregator/src/mk4storage/metakit/src/column.cpp
@@ -1398,30 +1398,30 @@ void c4_ColOfInts::ResizeData(int index_, int count_, bool clear_)
/* _currwidth 1: 2: 4:
* shiftPos 3 2 1 shift the offset right this much
* tqmaskPos 7 3 1 tqmask the offset with this
*/
const int shiftPos = _currWidth == 4 ? 1 : 4 - _currWidth;
- const int tqmaskPos = (1 << shiftPos) - 1;
+ const int maskPos = (1 << shiftPos) - 1;
// the following code is similar to c4_Column::Resize, but at bit level
// turn insertion into deletion by inserting entire bytes
if (count_ > 0) {
unsigned off = (unsigned) index_ >> shiftPos;
- int gapBytes = (count_ + tqmaskPos) >> shiftPos;
+ int gapBytes = (count_ + maskPos) >> shiftPos;
InsertData(off, gapBytes, clear_);
// oops, we might have inserted too low by a few entries
- const int bits = (index_ & tqmaskPos) * _currWidth;
+ const int bits = (index_ & maskPos) * _currWidth;
if (bits) {
- const int tqmaskLow = (1 << bits) - 1;
+ const int maskLow = (1 << bits) - 1;
// move the first few bits to start of inserted range
t4_byte* p = CopyNow(off + gapBytes);
- t4_byte one = *p & tqmaskLow;
- *p &= ~tqmaskLow;
+ t4_byte one = *p & maskLow;
+ *p &= ~maskLow;
* CopyNow(off) = one;
}
@@ -1398,30 +1398,30 @@ void c4_ColOfInts::ResizeData(int index_, int count_, bool clear_)
/* _currwidth 1: 2: 4:
* shiftPos 3 2 1 shift the offset right this much
- * tqmaskPos 7 3 1 tqmask the offset with this
+ * maskPos 7 3 1 tqmask the offset with this
*/
const int shiftPos = _currWidth == 4 ? 1 : 4 - _currWidth;